@@ -19,7 +19,7 @@ class Historic(Api):
             get_summary: Retrieves a list of Historic Summary for the given list of IDs
         """
 
-    def get_event(self, search_item, csv=False, limit=100, output_dir=None, extra_param=None):
+    def get_event(self, search_item, csv=False, connection_limit=100, output_dir=None, extra_param=None):
         """Retrieves historic event product data from the First Street Foundation API given a list of search_items and
         returns a list of Historic Event objects.
 
@@ -27,7 +27,7 @@ class Historic(Api):
             search_item (list/file): A First Street Foundation IDs, lat/lng pair, address, or a
                 file of First Street Foundation IDs
             csv (bool): To output extracted data to a csv or not
-            limit (int): max number of connections to make
+            connection_limit (int): max number of connections to make
             output_dir (str): The output directory to save the generated csvs
             extra_param (str): Extra parameter to be added to the url
 
@@ -36,7 +36,8 @@ class Historic(Api):
         """
 
         # Get data from api and create objects
-        api_datas = self.call_api(search_item, "historic", "event", None, limit=limit, extra_param=extra_param)
+        api_datas = self.call_api(search_item, "historic", "event", None,
+                                  connection_limit=connection_limit, extra_param=extra_param)
         product = [HistoricEvent(api_data) for api_data in api_datas]
 
         if csv:
@@ -46,7 +47,7 @@ class Historic(Api):
 
         return product
 
-    def get_events_by_location(self, search_item, location_type, csv=False, limit=100, output_dir=None,
+    def get_events_by_location(self, search_item, location_type, csv=False, connection_limit=100, output_dir=None,
                                extra_param=None):
         """Retrieves historic summary product data from the First Street Foundation API given a list of location
         search_items and returns a list of Historic Summary objects.
@@ -56,7 +57,7 @@ class Historic(Api):
                 file of First Street Foundation IDs
             location_type (str): The location lookup type
             csv (bool): To output extracted data to a csv or not
-            limit (int): max number of connections to make
+            connection_limit (int): max number of connections to make
             output_dir (str): The output directory to save the generated csvs
             extra_param (str): Extra parameter to be added to the url
 
@@ -73,14 +74,14 @@ class Historic(Api):
             raise TypeError("location is not a string")
 
         # Get data from api and create objects
-        api_datas = self.call_api(search_item, "historic", "summary", location_type, limit)
+        api_datas = self.call_api(search_item, "historic", "summary", location_type, connection_limit=connection_limit)
         summary = [HistoricSummary(api_data) for api_data in api_datas]
 
         search_item = list(set([event.get("eventId") for sum_hist in summary if sum_hist.historic for
                                 event in sum_hist.historic]))
 
         if search_item:
-            api_datas_event = self.call_api(search_item, "historic", "event", None, limit=limit,
+            api_datas_event = self.call_api(search_item, "historic", "event", None, connection_limit=connection_limit,
                                             extra_param=extra_param)
 
         else:
@@ -95,7 +96,8 @@ class Historic(Api):
 
         return [summary, event]
 
-    def get_summary(self, search_item, location_type, csv=False, limit=100, output_dir=None, extra_param=None):
+    def get_summary(self, search_item, location_type, csv=False,
+                    connection_limit=100, output_dir=None, extra_param=None):
         """Retrieves historic summary product data from the First Street Foundation API given a list of search_items and
         returns a list of Historic Summary objects.
 
@@ -104,7 +106,7 @@ class Historic(Api):
                 file of First Street Foundation IDs
             location_type (str): The location lookup type
             csv (bool): To output extracted data to a csv or not
-            limit (int): max number of connections to make
+            connection_limit (int): max number of connections to make
             output_dir (str): The output directory to save the generated csvs
             extra_param (str): Extra parameter to be added to the url
 
@@ -121,7 +123,7 @@ class Historic(Api):
             raise TypeError("location is not a string")
 
         # Get data from api and create objects
-        api_datas = self.call_api(search_item, "historic", "summary", location_type, limit=limit,
+        api_datas = self.call_api(search_item, "historic", "summary", location_type, connection_limit=connection_limit,
                                   extra_param=extra_param)
         product = [HistoricSummary(api_data) for api_data in api_datas]
 
